/* css.h: Prototypes and declarations for css.c
 * Copyright (C) 2007 Julian Graham
 *
 * libRUIN is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * libRUIN is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with libRUIN; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef RUIN_CSS_H
#define RUIN_CSS_H

#include "layout.h"
#include "util.h"

char *ruin_css_lookup(ruin_element_t *, char *, ruin_util_list *);
enum ruin_layout_foreground_color ruin_css_match_foreground_color(char *);
enum ruin_layout_background_color ruin_css_match_background_color
(char *, ruin_util_list *);
void ruin_css_clear_style_cache(ruin_element_t *);

#endif /* RUIN_CSS_H */
